@@ -1,3 +1,4 @@
+#[cfg(target_os="linux")]
 use std::thread::JoinHandle;
 
 use macroquad::prelude::Conf;
@@ -6,10 +7,18 @@ use crate::{render, LineDesc};
 
 pub type Matrix = Vec<Vec<f64>>;
 
+#[derive(Default)]
+pub struct AxisDesc {
+    pub title: String,
+    pub x_label: String,
+    pub y_label: String,
+}
+
 pub struct Plot {
     pub xs: Matrix,
     pub ys: Matrix,
     pub line_desc: Vec<LineDesc>,
+    pub axis_desc: AxisDesc,
 }
 
 impl Plot {
@@ -24,21 +33,35 @@ impl Plot {
         self.line_desc.push(plot.line_desc[0])
     }
 
-    pub fn show(self) {        
+    pub fn set_title(&mut self, title: &str) {
+        self.axis_desc.title = title.to_string();
+    }
+
+    pub fn set_xlabel(&mut self, label: &str) {
+        self.axis_desc.x_label = label.to_string();
+    }
+
+    pub fn set_ylabel(&mut self, label: &str) {
+        self.axis_desc.y_label = label.to_string();
+    }
+
+    pub fn show(self) {
         let conf = Conf {
-            window_width: 365,
-            window_height: 365,
+            window_title: self.axis_desc.title.clone(),
+            window_width: 395,
+            window_height: 395,
             ..Default::default()
         };
         macroquad::Window::from_config(conf, render::run(self));
     }
 
-    /// you will need another miniquad and macroquad version
+    #[cfg(target_os="linux")]
     pub fn show_threaded(self) -> JoinHandle<()> {
         std::thread::spawn(|| {
             let conf = Conf {
-                window_width: 365,
-                window_height: 365,
+                window_title: self.axis_desc.title.clone(),
+                window_width: 395,
+                window_height: 395,
                 ..Default::default()
             };
             macroquad::Window::from_config(conf, render::run(self));
@@ -46,12 +69,10 @@ impl Plot {
     }
 }
 
-
 #[derive(Clone, Copy)]
 pub struct XEnd(pub f64);
 pub struct YEnd(f64, f64);
 
-
 /// sets the absolute max value for x
 pub fn x(end_x: f64) -> XEnd {
     XEnd(end_x.abs())
@@ -63,47 +84,77 @@ pub trait PlotArg {
 
 impl<const N: usize> PlotArg for ([f64; N], [f64; N]) {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![self.0.to_vec()], ys: vec![self.1.to_vec()], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![self.0.to_vec()],
+            ys: vec![self.1.to_vec()],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl<const N: usize> PlotArg for ([f64; N], [f64; N], &str) {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![self.0.to_vec()], ys: vec![self.1.to_vec()], line_desc: vec![self.2.into()] }
+        Plot {
+            xs: vec![self.0.to_vec()],
+            ys: vec![self.1.to_vec()],
+            line_desc: vec![self.2.into()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl<const N: usize> PlotArg for [f64; N] {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![(0..N).map(|x| x as f64).collect()], ys: vec![self.to_vec()], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![(0..N).map(|x| x as f64).collect()],
+            ys: vec![self.to_vec()],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl<const N: usize> PlotArg for ([f64; N], &str) {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![(0..N).map(|x| x as f64).collect()], ys: vec![self.0.to_vec()], line_desc: vec![self.1.into()] }
+        Plot {
+            xs: vec![(0..N).map(|x| x as f64).collect()],
+            ys: vec![self.0.to_vec()],
+            line_desc: vec![self.1.into()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl PlotArg for Vec<f64> {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![(0..self.len()).map(|x| x as f64).collect()], ys: vec![self.clone()], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![(0..self.len()).map(|x| x as f64).collect()],
+            ys: vec![self.clone()],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl PlotArg for (Vec<f64>, &str) {
     fn as_plot(&self) -> Plot {
-        Plot { xs: vec![(0..self.0.len()).map(|x| x as f64).collect()], ys: vec![self.0.clone()], line_desc: vec![self.1.into()] }
+        Plot {
+            xs: vec![(0..self.0.len()).map(|x| x as f64).collect()],
+            ys: vec![self.0.clone()],
+            line_desc: vec![self.1.into()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl<F: Fn(f64) -> f64> PlotArg for F {
     fn as_plot(&self) -> Plot {
-        let mut xs = [0.; 20000]; 
-    
+        let mut xs = [0.; 20000];
+
         let mut add = -10000f64;
         for x in &mut xs {
-            *x = add/10000.;
+            *x = add / 10000.;
             add += 1.;
         }
 
@@ -111,17 +162,22 @@ impl<F: Fn(f64) -> f64> PlotArg for F {
         for (i, y) in ys.iter_mut().enumerate() {
             *y = self(xs[i]);
         }
-        Plot { xs: vec![xs.to_vec()], ys: vec![ys.to_vec()], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![xs.to_vec()],
+            ys: vec![ys.to_vec()],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
 impl<F: Fn(f64) -> f64> PlotArg for (F, XEnd) {
     fn as_plot(&self) -> Plot {
-        let mut xs = vec![0.; 200]; 
-    
+        let mut xs = vec![0.; 200];
+
         let mut add = -100f64;
         for x in &mut xs {
-            *x = (add/100.) * self.1.0;
+            *x = (add / 100.) * self.1 .0;
             add += 1.;
         }
 
@@ -129,11 +185,16 @@ impl<F: Fn(f64) -> f64> PlotArg for (F, XEnd) {
         for (i, y) in ys.iter_mut().enumerate() {
             *y = self.0(xs[i]);
         }
-        Plot { xs: vec![xs.to_vec()], ys: vec![ys.to_vec()], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![xs.to_vec()],
+            ys: vec![ys.to_vec()],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
-impl<F: Copy+Fn(f64) -> f64> PlotArg for (F, XEnd, &str) {
+impl<F: Copy + Fn(f64) -> f64> PlotArg for (F, XEnd, &str) {
     fn as_plot(&self) -> Plot {
         let mut plot = (self.0, self.1).as_plot();
         plot.line_desc = vec![self.2.into()];
@@ -141,7 +202,7 @@ impl<F: Copy+Fn(f64) -> f64> PlotArg for (F, XEnd, &str) {
     }
 }
 
-impl<F: Copy+Fn(f64) -> f64> PlotArg for (F, &str) {
+impl<F: Copy + Fn(f64) -> f64> PlotArg for (F, &str) {
     fn as_plot(&self) -> Plot {
         let mut plot = self.0.as_plot();
         plot.line_desc = vec![self.1.into()];
@@ -149,10 +210,10 @@ impl<F: Copy+Fn(f64) -> f64> PlotArg for (F, &str) {
     }
 }
 
-impl<F: Fn(f64) -> f64> PlotArg for (F, usize ) {
+impl<F: Fn(f64) -> f64> PlotArg for (F, usize) {
     fn as_plot(&self) -> Plot {
-        let mut xs = vec![0.; 20001]; 
-    
+        let mut xs = vec![0.; 20001];
+
         let mut add = -10000.;
         for x in &mut xs {
             *x = add / self.1 as f64;
@@ -164,14 +225,19 @@ impl<F: Fn(f64) -> f64> PlotArg for (F, usize ) {
             *y = self.0(xs[i]);
         }
 
-        Plot { xs: vec![xs], ys: vec![ys], line_desc: vec![Default::default()] }
+        Plot {
+            xs: vec![xs],
+            ys: vec![ys],
+            line_desc: vec![Default::default()],
+            axis_desc: Default::default(),
+        }
     }
 }
 
-impl<F: Copy+Fn(f64) -> f64> PlotArg for (F, usize, &str) {
+impl<F: Copy + Fn(f64) -> f64> PlotArg for (F, usize, &str) {
     fn as_plot(&self) -> Plot {
         let mut plot = (self.0, self.1).as_plot();
         plot.line_desc = vec![self.2.into()];
         plot
     }
-}
\ No newline at end of file
+}
